#line 2 "syncrep_scanner.c"

#line 4 "syncrep_scanner.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer syncrep_yy_create_buffer
#define yy_delete_buffer syncrep_yy_delete_buffer
#define yy_scan_buffer syncrep_yy_scan_buffer
#define yy_scan_string syncrep_yy_scan_string
#define yy_scan_bytes syncrep_yy_scan_bytes
#define yy_init_buffer syncrep_yy_init_buffer
#define yy_flush_buffer syncrep_yy_flush_buffer
#define yy_load_buffer_state syncrep_yy_load_buffer_state
#define yy_switch_to_buffer syncrep_yy_switch_to_buffer
#define yypush_buffer_state syncrep_yypush_buffer_state
#define yypop_buffer_state syncrep_yypop_buffer_state
#define yyensure_buffer_stack syncrep_yyensure_buffer_stack
#define yy_flex_debug syncrep_yy_flex_debug
#define yyin syncrep_yyin
#define yyleng syncrep_yyleng
#define yylex syncrep_yylex
#define yylineno syncrep_yylineno
#define yyout syncrep_yyout
#define yyrestart syncrep_yyrestart
#define yytext syncrep_yytext
#define yywrap syncrep_yywrap
#define yyalloc syncrep_yyalloc
#define yyrealloc syncrep_yyrealloc
#define yyfree syncrep_yyfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define syncrep_yy_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer syncrep_yy_create_buffer
#endif

#ifdef yy_delete_buffer
#define syncrep_yy_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer syncrep_yy_delete_buffer
#endif

#ifdef yy_scan_buffer
#define syncrep_yy_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer syncrep_yy_scan_buffer
#endif

#ifdef yy_scan_string
#define syncrep_yy_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string syncrep_yy_scan_string
#endif

#ifdef yy_scan_bytes
#define syncrep_yy_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes syncrep_yy_scan_bytes
#endif

#ifdef yy_init_buffer
#define syncrep_yy_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer syncrep_yy_init_buffer
#endif

#ifdef yy_flush_buffer
#define syncrep_yy_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer syncrep_yy_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define syncrep_yy_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state syncrep_yy_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define syncrep_yy_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer syncrep_yy_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define syncrep_yypush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state syncrep_yypush_buffer_state
#endif

#ifdef yypop_buffer_state
#define syncrep_yypop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state syncrep_yypop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define syncrep_yyensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack syncrep_yyensure_buffer_stack
#endif

#ifdef yylex
#define syncrep_yylex_ALREADY_DEFINED
#else
#define yylex syncrep_yylex
#endif

#ifdef yyrestart
#define syncrep_yyrestart_ALREADY_DEFINED
#else
#define yyrestart syncrep_yyrestart
#endif

#ifdef yylex_init
#define syncrep_yylex_init_ALREADY_DEFINED
#else
#define yylex_init syncrep_yylex_init
#endif

#ifdef yylex_init_extra
#define syncrep_yylex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra syncrep_yylex_init_extra
#endif

#ifdef yylex_destroy
#define syncrep_yylex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy syncrep_yylex_destroy
#endif

#ifdef yyget_debug
#define syncrep_yyget_debug_ALREADY_DEFINED
#else
#define yyget_debug syncrep_yyget_debug
#endif

#ifdef yyset_debug
#define syncrep_yyset_debug_ALREADY_DEFINED
#else
#define yyset_debug syncrep_yyset_debug
#endif

#ifdef yyget_extra
#define syncrep_yyget_extra_ALREADY_DEFINED
#else
#define yyget_extra syncrep_yyget_extra
#endif

#ifdef yyset_extra
#define syncrep_yyset_extra_ALREADY_DEFINED
#else
#define yyset_extra syncrep_yyset_extra
#endif

#ifdef yyget_in
#define syncrep_yyget_in_ALREADY_DEFINED
#else
#define yyget_in syncrep_yyget_in
#endif

#ifdef yyset_in
#define syncrep_yyset_in_ALREADY_DEFINED
#else
#define yyset_in syncrep_yyset_in
#endif

#ifdef yyget_out
#define syncrep_yyget_out_ALREADY_DEFINED
#else
#define yyget_out syncrep_yyget_out
#endif

#ifdef yyset_out
#define syncrep_yyset_out_ALREADY_DEFINED
#else
#define yyset_out syncrep_yyset_out
#endif

#ifdef yyget_leng
#define syncrep_yyget_leng_ALREADY_DEFINED
#else
#define yyget_leng syncrep_yyget_leng
#endif

#ifdef yyget_text
#define syncrep_yyget_text_ALREADY_DEFINED
#else
#define yyget_text syncrep_yyget_text
#endif

#ifdef yyget_lineno
#define syncrep_yyget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno syncrep_yyget_lineno
#endif

#ifdef yyset_lineno
#define syncrep_yyset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno syncrep_yyset_lineno
#endif

#ifdef yywrap
#define syncrep_yywrap_ALREADY_DEFINED
#else
#define yywrap syncrep_yywrap
#endif

#ifdef yyalloc
#define syncrep_yyalloc_ALREADY_DEFINED
#else
#define yyalloc syncrep_yyalloc
#endif

#ifdef yyrealloc
#define syncrep_yyrealloc_ALREADY_DEFINED
#else
#define yyrealloc syncrep_yyrealloc
#endif

#ifdef yyfree
#define syncrep_yyfree_ALREADY_DEFINED
#else
#define yyfree syncrep_yyfree
#endif

#ifdef yytext
#define syncrep_yytext_ALREADY_DEFINED
#else
#define yytext syncrep_yytext
#endif

#ifdef yyleng
#define syncrep_yyleng_ALREADY_DEFINED
#else
#define yyleng syncrep_yyleng
#endif

#ifdef yyin
#define syncrep_yyin_ALREADY_DEFINED
#else
#define yyin syncrep_yyin
#endif

#ifdef yyout
#define syncrep_yyout_ALREADY_DEFINED
#else
#define yyout syncrep_yyout
#endif

#ifdef yy_flex_debug
#define syncrep_yy_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug syncrep_yy_flex_debug
#endif

#ifdef yylineno
#define syncrep_yylineno_ALREADY_DEFINED
#else
#define yylineno syncrep_yylineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define syncrep_yywrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef const struct yy_trans_info *yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 13
#define YY_END_OF_BUFFER 14
struct yy_trans_info
	{
	flex_int16_t yy_verify;
	flex_int16_t yy_nxt;
	};
static const struct yy_trans_info yy_transition[2382] =
    {
 {   0,   0 }, {   0,2126 }, {   0,   0 }, {   0,2124 }, {   1,1032 },
 {   2,1032 }, {   3,1032 }, {   4,1032 }, {   5,1032 }, {   6,1032 },
 {   7,1032 }, {   8,1032 }, {   9,1034 }, {  10,1039 }, {  11,1034 },
 {  12,1034 }, {  13,1034 }, {  14,1032 }, {  15,1032 }, {  16,1032 },
 {  17,1032 }, {  18,1032 }, {  19,1032 }, {  20,1032 }, {  21,1032 },
 {  22,1032 }, {  23,1032 }, {  24,1032 }, {  25,1032 }, {  26,1032 },
 {  27,1032 }, {  28,1032 }, {  29,1032 }, {  30,1032 }, {  31,1032 },
 {  32,1034 }, {  33,1032 }, {  34,1036 }, {  35,1032 }, {  36,1032 },
 {  37,1032 }, {  38,1032 }, {  39,1032 }, {  40,1041 }, {  41,1054 },
 {  42,1056 }, {  43,1032 }, {  44,1058 }, {  45,1032 }, {  46,1032 },

 {  47,1032 }, {  48,1060 }, {  49,1060 }, {  50,1060 }, {  51,1060 },
 {  52,1060 }, {  53,1060 }, {  54,1060 }, {  55,1060 }, {  56,1060 },
 {  57,1060 }, {  58,1032 }, {  59,1032 }, {  60,1032 }, {  61,1032 },
 {  62,1032 }, {  63,1032 }, {  64,1032 }, {  65,1070 }, {  66,1070 },
 {  67,1070 }, {  68,1070 }, {  69,1070 }, {  70,1070 }, {  71,1070 },
 {  72,1070 }, {  73,1070 }, {  74,1070 }, {  75,1070 }, {  76,1070 },
 {  77,1070 }, {  78,1070 }, {  79,1070 }, {  80,1070 }, {  81,1070 },
 {  82,1070 }, {  83,1070 }, {  84,1070 }, {  85,1070 }, {  86,1070 },
 {  87,1070 }, {  88,1070 }, {  89,1070 }, {  90,1070 }, {  91,1032 },
 {  92,1032 }, {  93,1032 }, {  94,1032 }, {  95,1070 }, {  96,1032 },

 {  97,1070 }, {  98,1070 }, {  99,1070 }, { 100,1070 }, { 101,1070 },
 { 102,1070 }, { 103,1070 }, { 104,1070 }, { 105,1070 }, { 106,1070 },
 { 107,1070 }, { 108,1070 }, { 109,1070 }, { 110,1070 }, { 111,1070 },
 { 112,1070 }, { 113,1070 }, { 114,1070 }, { 115,1070 }, { 116,1070 },
 { 117,1070 }, { 118,1070 }, { 119,1070 }, { 120,1070 }, { 121,1070 },
 { 122,1070 }, { 123,1032 }, { 124,1032 }, { 125,1032 }, { 126,1032 },
 { 127,1032 }, { 128,1070 }, { 129,1070 }, { 130,1070 }, { 131,1070 },
 { 132,1070 }, { 133,1070 }, { 134,1070 }, { 135,1070 }, { 136,1070 },
 { 137,1070 }, { 138,1070 }, { 139,1070 }, { 140,1070 }, { 141,1070 },
 { 142,1070 }, { 143,1070 }, { 144,1070 }, { 145,1070 }, { 146,1070 },

 { 147,1070 }, { 148,1070 }, { 149,1070 }, { 150,1070 }, { 151,1070 },
 { 152,1070 }, { 153,1070 }, { 154,1070 }, { 155,1070 }, { 156,1070 },
 { 157,1070 }, { 158,1070 }, { 159,1070 }, { 160,1070 }, { 161,1070 },
 { 162,1070 }, { 163,1070 }, { 164,1070 }, { 165,1070 }, { 166,1070 },
 { 167,1070 }, { 168,1070 }, { 169,1070 }, { 170,1070 }, { 171,1070 },
 { 172,1070 }, { 173,1070 }, { 174,1070 }, { 175,1070 }, { 176,1070 },
 { 177,1070 }, { 178,1070 }, { 179,1070 }, { 180,1070 }, { 181,1070 },
 { 182,1070 }, { 183,1070 }, { 184,1070 }, { 185,1070 }, { 186,1070 },
 { 187,1070 }, { 188,1070 }, { 189,1070 }, { 190,1070 }, { 191,1070 },
 { 192,1070 }, { 193,1070 }, { 194,1070 }, { 195,1070 }, { 196,1070 },

 { 197,1070 }, { 198,1070 }, { 199,1070 }, { 200,1070 }, { 201,1070 },
 { 202,1070 }, { 203,1070 }, { 204,1070 }, { 205,1070 }, { 206,1070 },
 { 207,1070 }, { 208,1070 }, { 209,1070 }, { 210,1070 }, { 211,1070 },
 { 212,1070 }, { 213,1070 }, { 214,1070 }, { 215,1070 }, { 216,1070 },
 { 217,1070 }, { 218,1070 }, { 219,1070 }, { 220,1070 }, { 221,1070 },
 { 222,1070 }, { 223,1070 }, { 224,1070 }, { 225,1070 }, { 226,1070 },
 { 227,1070 }, { 228,1070 }, { 229,1070 }, { 230,1070 }, { 231,1070 },
 { 232,1070 }, { 233,1070 }, { 234,1070 }, { 235,1070 }, { 236,1070 },
 { 237,1070 }, { 238,1070 }, { 239,1070 }, { 240,1070 }, { 241,1070 },
 { 242,1070 }, { 243,1070 }, { 244,1070 }, { 245,1070 }, { 246,1070 },

 { 247,1070 }, { 248,1070 }, { 249,1070 }, { 250,1070 }, { 251,1070 },
 { 252,1070 }, { 253,1070 }, { 254,1070 }, { 255,1070 }, { 256,1032 },
 {   0,   0 }, {   0,1866 }, {   1, 774 }, {   2, 774 }, {   3, 774 },
 {   4, 774 }, {   5, 774 }, {   6, 774 }, {   7, 774 }, {   8, 774 },
 {   9, 776 }, {  10, 781 }, {  11, 776 }, {  12, 776 }, {  13, 776 },
 {  14, 774 }, {  15, 774 }, {  16, 774 }, {  17, 774 }, {  18, 774 },
 {  19, 774 }, {  20, 774 }, {  21, 774 }, {  22, 774 }, {  23, 774 },
 {  24, 774 }, {  25, 774 }, {  26, 774 }, {  27, 774 }, {  28, 774 },
 {  29, 774 }, {  30, 774 }, {  31, 774 }, {  32, 776 }, {  33, 774 },
 {  34, 778 }, {  35, 774 }, {  36, 774 }, {  37, 774 }, {  38, 774 },

 {  39, 774 }, {  40, 783 }, {  41, 796 }, {  42, 798 }, {  43, 774 },
 {  44, 800 }, {  45, 774 }, {  46, 774 }, {  47, 774 }, {  48, 802 },
 {  49, 802 }, {  50, 802 }, {  51, 802 }, {  52, 802 }, {  53, 802 },
 {  54, 802 }, {  55, 802 }, {  56, 802 }, {  57, 802 }, {  58, 774 },
 {  59, 774 }, {  60, 774 }, {  61, 774 }, {  62, 774 }, {  63, 774 },
 {  64, 774 }, {  65, 812 }, {  66, 812 }, {  67, 812 }, {  68, 812 },
 {  69, 812 }, {  70, 812 }, {  71, 812 }, {  72, 812 }, {  73, 812 },
 {  74, 812 }, {  75, 812 }, {  76, 812 }, {  77, 812 }, {  78, 812 },
 {  79, 812 }, {  80, 812 }, {  81, 812 }, {  82, 812 }, {  83, 812 },
 {  84, 812 }, {  85, 812 }, {  86, 812 }, {  87, 812 }, {  88, 812 },

 {  89, 812 }, {  90, 812 }, {  91, 774 }, {  92, 774 }, {  93, 774 },
 {  94, 774 }, {  95, 812 }, {  96, 774 }, {  97, 812 }, {  98, 812 },
 {  99, 812 }, { 100, 812 }, { 101, 812 }, { 102, 812 }, { 103, 812 },
 { 104, 812 }, { 105, 812 }, { 106, 812 }, { 107, 812 }, { 108, 812 },
 { 109, 812 }, { 110, 812 }, { 111, 812 }, { 112, 812 }, { 113, 812 },
 { 114, 812 }, { 115, 812 }, { 116, 812 }, { 117, 812 }, { 118, 812 },
 { 119, 812 }, { 120, 812 }, { 121, 812 }, { 122, 812 }, { 123, 774 },
 { 124, 774 }, { 125, 774 }, { 126, 774 }, { 127, 774 }, { 128, 812 },
 { 129, 812 }, { 130, 812 }, { 131, 812 }, { 132, 812 }, { 133, 812 },
 { 134, 812 }, { 135, 812 }, { 136, 812 }, { 137, 812 }, { 138, 812 },

 { 139, 812 }, { 140, 812 }, { 141, 812 }, { 142, 812 }, { 143, 812 },
 { 144, 812 }, { 145, 812 }, { 146, 812 }, { 147, 812 }, { 148, 812 },
 { 149, 812 }, { 150, 812 }, { 151, 812 }, { 152, 812 }, { 153, 812 },
 { 154, 812 }, { 155, 812 }, { 156, 812 }, { 157, 812 }, { 158, 812 },
 { 159, 812 }, { 160, 812 }, { 161, 812 }, { 162, 812 }, { 163, 812 },
 { 164, 812 }, { 165, 812 }, { 166, 812 }, { 167, 812 }, { 168, 812 },
 { 169, 812 }, { 170, 812 }, { 171, 812 }, { 172, 812 }, { 173, 812 },
 { 174, 812 }, { 175, 812 }, { 176, 812 }, { 177, 812 }, { 178, 812 },
 { 179, 812 }, { 180, 812 }, { 181, 812 }, { 182, 812 }, { 183, 812 },
 { 184, 812 }, { 185, 812 }, { 186, 812 }, { 187, 812 }, { 188, 812 },

 { 189, 812 }, { 190, 812 }, { 191, 812 }, { 192, 812 }, { 193, 812 },
 { 194, 812 }, { 195, 812 }, { 196, 812 }, { 197, 812 }, { 198, 812 },
 { 199, 812 }, { 200, 812 }, { 201, 812 }, { 202, 812 }, { 203, 812 },
 { 204, 812 }, { 205, 812 }, { 206, 812 }, { 207, 812 }, { 208, 812 },
 { 209, 812 }, { 210, 812 }, { 211, 812 }, { 212, 812 }, { 213, 812 },
 { 214, 812 }, { 215, 812 }, { 216, 812 }, { 217, 812 }, { 218, 812 },
 { 219, 812 }, { 220, 812 }, { 221, 812 }, { 222, 812 }, { 223, 812 },
 { 224, 812 }, { 225, 812 }, { 226, 812 }, { 227, 812 }, { 228, 812 },
 { 229, 812 }, { 230, 812 }, { 231, 812 }, { 232, 812 }, { 233, 812 },
 { 234, 812 }, { 235, 812 }, { 236, 812 }, { 237, 812 }, { 238, 812 },

 { 239, 812 }, { 240, 812 }, { 241, 812 }, { 242, 812 }, { 243, 812 },
 { 244, 812 }, { 245, 812 }, { 246, 812 }, { 247, 812 }, { 248, 812 },
 { 249, 812 }, { 250, 812 }, { 251, 812 }, { 252, 812 }, { 253, 812 },
 { 254, 812 }, { 255, 812 }, { 256, 774 }, {   0,   0 }, {   0,1608 },
 {   1, 811 }, {   2, 811 }, {   3, 811 }, {   4, 811 }, {   5, 811 },
 {   6, 811 }, {   7, 811 }, {   8, 811 }, {   9, 811 }, {  10, 811 },
 {  11, 811 }, {  12, 811 }, {  13, 811 }, {  14, 811 }, {  15, 811 },
 {  16, 811 }, {  17, 811 }, {  18, 811 }, {  19, 811 }, {  20, 811 },
 {  21, 811 }, {  22, 811 }, {  23, 811 }, {  24, 811 }, {  25, 811 },
 {  26, 811 }, {  27, 811 }, {  28, 811 }, {  29, 811 }, {  30, 811 },

 {  31, 811 }, {  32, 811 }, {  33, 811 }, {  34, 546 }, {  35, 811 },
 {  36, 811 }, {  37, 811 }, {  38, 811 }, {  39, 811 }, {  40, 811 },
 {  41, 811 }, {  42, 811 }, {  43, 811 }, {  44, 811 }, {  45, 811 },
 {  46, 811 }, {  47, 811 }, {  48, 811 }, {  49, 811 }, {  50, 811 },
 {  51, 811 }, {  52, 811 }, {  53, 811 }, {  54, 811 }, {  55, 811 },
 {  56, 811 }, {  57, 811 }, {  58, 811 }, {  59, 811 }, {  60, 811 },
 {  61, 811 }, {  62, 811 }, {  63, 811 }, {  64, 811 }, {  65, 811 },
 {  66, 811 }, {  67, 811 }, {  68, 811 }, {  69, 811 }, {  70, 811 },
 {  71, 811 }, {  72, 811 }, {  73, 811 }, {  74, 811 }, {  75, 811 },
 {  76, 811 }, {  77, 811 }, {  78, 811 }, {  79, 811 }, {  80, 811 },

 {  81, 811 }, {  82, 811 }, {  83, 811 }, {  84, 811 }, {  85, 811 },
 {  86, 811 }, {  87, 811 }, {  88, 811 }, {  89, 811 }, {  90, 811 },
 {  91, 811 }, {  92, 811 }, {  93, 811 }, {  94, 811 }, {  95, 811 },
 {  96, 811 }, {  97, 811 }, {  98, 811 }, {  99, 811 }, { 100, 811 },
 { 101, 811 }, { 102, 811 }, { 103, 811 }, { 104, 811 }, { 105, 811 },
 { 106, 811 }, { 107, 811 }, { 108, 811 }, { 109, 811 }, { 110, 811 },
 { 111, 811 }, { 112, 811 }, { 113, 811 }, { 114, 811 }, { 115, 811 },
 { 116, 811 }, { 117, 811 }, { 118, 811 }, { 119, 811 }, { 120, 811 },
 { 121, 811 }, { 122, 811 }, { 123, 811 }, { 124, 811 }, { 125, 811 },
 { 126, 811 }, { 127, 811 }, { 128, 811 }, { 129, 811 }, { 130, 811 },

 { 131, 811 }, { 132, 811 }, { 133, 811 }, { 134, 811 }, { 135, 811 },
 { 136, 811 }, { 137, 811 }, { 138, 811 }, { 139, 811 }, { 140, 811 },
 { 141, 811 }, { 142, 811 }, { 143, 811 }, { 144, 811 }, { 145, 811 },
 { 146, 811 }, { 147, 811 }, { 148, 811 }, { 149, 811 }, { 150, 811 },
 { 151, 811 }, { 152, 811 }, { 153, 811 }, { 154, 811 }, { 155, 811 },
 { 156, 811 }, { 157, 811 }, { 158, 811 }, { 159, 811 }, { 160, 811 },
 { 161, 811 }, { 162, 811 }, { 163, 811 }, { 164, 811 }, { 165, 811 },
 { 166, 811 }, { 167, 811 }, { 168, 811 }, { 169, 811 }, { 170, 811 },
 { 171, 811 }, { 172, 811 }, { 173, 811 }, { 174, 811 }, { 175, 811 },
 { 176, 811 }, { 177, 811 }, { 178, 811 }, { 179, 811 }, { 180, 811 },

 { 181, 811 }, { 182, 811 }, { 183, 811 }, { 184, 811 }, { 185, 811 },
 { 186, 811 }, { 187, 811 }, { 188, 811 }, { 189, 811 }, { 190, 811 },
 { 191, 811 }, { 192, 811 }, { 193, 811 }, { 194, 811 }, { 195, 811 },
 { 196, 811 }, { 197, 811 }, { 198, 811 }, { 199, 811 }, { 200, 811 },
 { 201, 811 }, { 202, 811 }, { 203, 811 }, { 204, 811 }, { 205, 811 },
 { 206, 811 }, { 207, 811 }, { 208, 811 }, { 209, 811 }, { 210, 811 },
 { 211, 811 }, { 212, 811 }, { 213, 811 }, { 214, 811 }, { 215, 811 },
 { 216, 811 }, { 217, 811 }, { 218, 811 }, { 219, 811 }, { 220, 811 },
 { 221, 811 }, { 222, 811 }, { 223, 811 }, { 224, 811 }, { 225, 811 },
 { 226, 811 }, { 227, 811 }, { 228, 811 }, { 229, 811 }, { 230, 811 },

 { 231, 811 }, { 232, 811 }, { 233, 811 }, { 234, 811 }, { 235, 811 },
 { 236, 811 }, { 237, 811 }, { 238, 811 }, { 239, 811 }, { 240, 811 },
 { 241, 811 }, { 242, 811 }, { 243, 811 }, { 244, 811 }, { 245, 811 },
 { 246, 811 }, { 247, 811 }, { 248, 811 }, { 249, 811 }, { 250, 811 },
 { 251, 811 }, { 252, 811 }, { 253, 811 }, { 254, 811 }, { 255, 811 },
 { 256, 811 }, {   0,   0 }, {   0,1350 }, {   1, 553 }, {   2, 553 },
 {   3, 553 }, {   4, 553 }, {   5, 553 }, {   6, 553 }, {   7, 553 },
 {   8, 553 }, {   9, 553 }, {  10, 553 }, {  11, 553 }, {  12, 553 },
 {  13, 553 }, {  14, 553 }, {  15, 553 }, {  16, 553 }, {  17, 553 },
 {  18, 553 }, {  19, 553 }, {  20, 553 }, {  21, 553 }, {  22, 553 },

 {  23, 553 }, {  24, 553 }, {  25, 553 }, {  26, 553 }, {  27, 553 },
 {  28, 553 }, {  29, 553 }, {  30, 553 }, {  31, 553 }, {  32, 553 },
 {  33, 553 }, {  34, 288 }, {  35, 553 }, {  36, 553 }, {  37, 553 },
 {  38, 553 }, {  39, 553 }, {  40, 553 }, {  41, 553 }, {  42, 553 },
 {  43, 553 }, {  44, 553 }, {  45, 553 }, {  46, 553 }, {  47, 553 },
 {  48, 553 }, {  49, 553 }, {  50, 553 }, {  51, 553 }, {  52, 553 },
 {  53, 553 }, {  54, 553 }, {  55, 553 }, {  56, 553 }, {  57, 553 },
 {  58, 553 }, {  59, 553 }, {  60, 553 }, {  61, 553 }, {  62, 553 },
 {  63, 553 }, {  64, 553 }, {  65, 553 }, {  66, 553 }, {  67, 553 },
 {  68, 553 }, {  69, 553 }, {  70, 553 }, {  71, 553 }, {  72, 553 },

 {  73, 553 }, {  74, 553 }, {  75, 553 }, {  76, 553 }, {  77, 553 },
 {  78, 553 }, {  79, 553 }, {  80, 553 }, {  81, 553 }, {  82, 553 },
 {  83, 553 }, {  84, 553 }, {  85, 553 }, {  86, 553 }, {  87, 553 },
 {  88, 553 }, {  89, 553 }, {  90, 553 }, {  91, 553 }, {  92, 553 },
 {  93, 553 }, {  94, 553 }, {  95, 553 }, {  96, 553 }, {  97, 553 },
 {  98, 553 }, {  99, 553 }, { 100, 553 }, { 101, 553 }, { 102, 553 },
 { 103, 553 }, { 104, 553 }, { 105, 553 }, { 106, 553 }, { 107, 553 },
 { 108, 553 }, { 109, 553 }, { 110, 553 }, { 111, 553 }, { 112, 553 },
 { 113, 553 }, { 114, 553 }, { 115, 553 }, { 116, 553 }, { 117, 553 },
 { 118, 553 }, { 119, 553 }, { 120, 553 }, { 121, 553 }, { 122, 553 },

 { 123, 553 }, { 124, 553 }, { 125, 553 }, { 126, 553 }, { 127, 553 },
 { 128, 553 }, { 129, 553 }, { 130, 553 }, { 131, 553 }, { 132, 553 },
 { 133, 553 }, { 134, 553 }, { 135, 553 }, { 136, 553 }, { 137, 553 },
 { 138, 553 }, { 139, 553 }, { 140, 553 }, { 141, 553 }, { 142, 553 },
 { 143, 553 }, { 144, 553 }, { 145, 553 }, { 146, 553 }, { 147, 553 },
 { 148, 553 }, { 149, 553 }, { 150, 553 }, { 151, 553 }, { 152, 553 },
 { 153, 553 }, { 154, 553 }, { 155, 553 }, { 156, 553 }, { 157, 553 },
 { 158, 553 }, { 159, 553 }, { 160, 553 }, { 161, 553 }, { 162, 553 },
 { 163, 553 }, { 164, 553 }, { 165, 553 }, { 166, 553 }, { 167, 553 },
 { 168, 553 }, { 169, 553 }, { 170, 553 }, { 171, 553 }, { 172, 553 },

 { 173, 553 }, { 174, 553 }, { 175, 553 }, { 176, 553 }, { 177, 553 },
 { 178, 553 }, { 179, 553 }, { 180, 553 }, { 181, 553 }, { 182, 553 },
 { 183, 553 }, { 184, 553 }, { 185, 553 }, { 186, 553 }, { 187, 553 },
 { 188, 553 }, { 189, 553 }, { 190, 553 }, { 191, 553 }, { 192, 553 },
 { 193, 553 }, { 194, 553 }, { 195, 553 }, { 196, 553 }, { 197, 553 },
 { 198, 553 }, { 199, 553 }, { 200, 553 }, { 201, 553 }, { 202, 553 },
 { 203, 553 }, { 204, 553 }, { 205, 553 }, { 206, 553 }, { 207, 553 },
 { 208, 553 }, { 209, 553 }, { 210, 553 }, { 211, 553 }, { 212, 553 },
 { 213, 553 }, { 214, 553 }, { 215, 553 }, { 216, 553 }, { 217, 553 },
 { 218, 553 }, { 219, 553 }, { 220, 553 }, { 221, 553 }, { 222, 553 },

 { 223, 553 }, { 224, 553 }, { 225, 553 }, { 226, 553 }, { 227, 553 },
 { 228, 553 }, { 229, 553 }, { 230, 553 }, { 231, 553 }, { 232, 553 },
 { 233, 553 }, { 234, 553 }, { 235, 553 }, { 236, 553 }, { 237, 553 },
 { 238, 553 }, { 239, 553 }, { 240, 553 }, { 241, 553 }, { 242, 553 },
 { 243, 553 }, { 244, 553 }, { 245, 553 }, { 246, 553 }, { 247, 553 },
 { 248, 553 }, { 249, 553 }, { 250, 553 }, { 251, 553 }, { 252, 553 },
 { 253, 553 }, { 254, 553 }, { 255, 553 }, { 256, 553 }, {   0,  12 },
 {   0,1092 }, {   0,   1 }, {   0,1090 }, {   0,   2 }, {   0,1088 },
 {   0,   0 }, {   0,   1 }, {   0,1085 }, {   0,  10 }, {   0,1083 },
 {   0,   0 }, {   9, 551 }, {  10, 551 }, {  11, 551 }, {  12, 551 },

 {  13, 551 }, {   9, 546 }, {  10, 546 }, {  11, 546 }, {  12, 546 },
 {  13, 546 }, {   0,  11 }, {   0,1070 }, {   0,   8 }, {   0,1068 },
 {   0,   9 }, {   0,1066 }, {   0,   7 }, {   0,1064 }, {   0,   5 },
 {   0,1062 }, {   0,   3 }, {   0,1060 }, {   0,   0 }, {  32, 551 },
 {   0,   0 }, {   0,   0 }, {   0,   6 }, {   0,1054 }, {  32, 546 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  34,   2 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  36, 539 },
 {   0,   0 }, {  48, 527 }, {  49, 527 }, {  50, 527 }, {  51, 527 },
 {  52, 527 }, {  53, 527 }, {  54, 527 }, {  55, 527 }, {  56, 527 },
 {  57, 527 }, {  48, 539 }, {  49, 539 }, {  50, 539 }, {  51, 539 },
 {  52, 539 }, {  53, 539 }, {  54, 539 }, {  55, 539 }, {  56, 539 },
 {  57, 539 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65, 539 }, {  66, 539 },
 {  67, 539 }, {  68, 539 }, {  69, 539 }, {  70, 539 }, {  71, 539 },
 {  72, 539 }, {  73, 539 }, {  74, 539 }, {  75, 539 }, {  76, 539 },

 {  77, 539 }, {  78, 539 }, {  79, 539 }, {  80, 539 }, {  81, 539 },
 {  82, 539 }, {  83, 539 }, {  84, 539 }, {  85, 539 }, {  86, 539 },
 {  87, 539 }, {  88, 539 }, {  89, 539 }, {  90, 539 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95, 539 }, {   0,   0 },
 {  97, 539 }, {  98, 539 }, {  99, 539 }, { 100, 539 }, { 101, 539 },
 { 102, 539 }, { 103, 539 }, { 104, 539 }, { 105, 539 }, { 106, 539 },
 { 107, 539 }, { 108, 539 }, { 109, 539 }, { 110, 539 }, { 111, 539 },
 { 112, 539 }, { 113, 539 }, { 114, 539 }, { 115, 539 }, { 116, 539 },
 { 117, 539 }, { 118, 539 }, { 119, 539 }, { 120, 539 }, { 121, 539 },
 { 122, 539 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, { 128, 539 }, { 129, 539 }, { 130, 539 }, { 131, 539 },
 { 132, 539 }, { 133, 539 }, { 134, 539 }, { 135, 539 }, { 136, 539 },
 { 137, 539 }, { 138, 539 }, { 139, 539 }, { 140, 539 }, { 141, 539 },
 { 142, 539 }, { 143, 539 }, { 144, 539 }, { 145, 539 }, { 146, 539 },
 { 147, 539 }, { 148, 539 }, { 149, 539 }, { 150, 539 }, { 151, 539 },
 { 152, 539 }, { 153, 539 }, { 154, 539 }, { 155, 539 }, { 156, 539 },
 { 157, 539 }, { 158, 539 }, { 159, 539 }, { 160, 539 }, { 161, 539 },
 { 162, 539 }, { 163, 539 }, { 164, 539 }, { 165, 539 }, { 166, 539 },
 { 167, 539 }, { 168, 539 }, { 169, 539 }, { 170, 539 }, { 171, 539 },
 { 172, 539 }, { 173, 539 }, { 174, 539 }, { 175, 539 }, { 176, 539 },

 { 177, 539 }, { 178, 539 }, { 179, 539 }, { 180, 539 }, { 181, 539 },
 { 182, 539 }, { 183, 539 }, { 184, 539 }, { 185, 539 }, { 186, 539 },
 { 187, 539 }, { 188, 539 }, { 189, 539 }, { 190, 539 }, { 191, 539 },
 { 192, 539 }, { 193, 539 }, { 194, 539 }, { 195, 539 }, { 196, 539 },
 { 197, 539 }, { 198, 539 }, { 199, 539 }, { 200, 539 }, { 201, 539 },
 { 202, 539 }, { 203, 539 }, { 204, 539 }, { 205, 539 }, { 206, 539 },
 { 207, 539 }, { 208, 539 }, { 209, 539 }, { 210, 539 }, { 211, 539 },
 { 212, 539 }, { 213, 539 }, { 214, 539 }, { 215, 539 }, { 216, 539 },
 { 217, 539 }, { 218, 539 }, { 219, 539 }, { 220, 539 }, { 221, 539 },
 { 222, 539 }, { 223, 539 }, { 224, 539 }, { 225, 539 }, { 226, 539 },

 { 227, 539 }, { 228, 539 }, { 229, 539 }, { 230, 539 }, { 231, 539 },
 { 232, 539 }, { 233, 539 }, { 234, 539 }, { 235, 539 }, { 236, 539 },
 { 237, 539 }, { 238, 539 }, { 239, 539 }, { 240, 539 }, { 241, 539 },
 { 242, 539 }, { 243, 539 }, { 244, 539 }, { 245, 539 }, { 246, 539 },
 { 247, 539 }, { 248, 539 }, { 249, 539 }, { 250, 539 }, { 251, 539 },
 { 252, 539 }, { 253, 539 }, { 254, 539 }, { 255, 539 }, {   0,   4 },
 {   0, 797 }, {   1, 539 }, {   2, 539 }, {   3, 539 }, {   4, 539 },
 {   5, 539 }, {   6, 539 }, {   7, 539 }, {   8, 539 }, {   9, 539 },
 {  10, 539 }, {  11, 539 }, {  12, 539 }, {  13, 539 }, {  14, 539 },
 {  15, 539 }, {  16, 539 }, {  17, 539 }, {  18, 539 }, {  19, 539 },

 {  20, 539 }, {  21, 539 }, {  22, 539 }, {  23, 539 }, {  24, 539 },
 {  25, 539 }, {  26, 539 }, {  27, 539 }, {  28, 539 }, {  29, 539 },
 {  30, 539 }, {  31, 539 }, {  32, 539 }, {  33, 539 }, {   0,   0 },
 {  35, 539 }, {  36, 539 }, {  37, 539 }, {  38, 539 }, {  39, 539 },
 {  40, 539 }, {  41, 539 }, {  42, 539 }, {  43, 539 }, {  44, 539 },
 {  45, 539 }, {  46, 539 }, {  47, 539 }, {  48, 539 }, {  49, 539 },
 {  50, 539 }, {  51, 539 }, {  52, 539 }, {  53, 539 }, {  54, 539 },
 {  55, 539 }, {  56, 539 }, {  57, 539 }, {  58, 539 }, {  59, 539 },
 {  60, 539 }, {  61, 539 }, {  62, 539 }, {  63, 539 }, {  64, 539 },
 {  65, 539 }, {  66, 539 }, {  67, 539 }, {  68, 539 }, {  69, 539 },

 {  70, 539 }, {  71, 539 }, {  72, 539 }, {  73, 539 }, {  74, 539 },
 {  75, 539 }, {  76, 539 }, {  77, 539 }, {  78, 539 }, {  79, 539 },
 {  80, 539 }, {  81, 539 }, {  82, 539 }, {  83, 539 }, {  84, 539 },
 {  85, 539 }, {  86, 539 }, {  87, 539 }, {  88, 539 }, {  89, 539 },
 {  90, 539 }, {  91, 539 }, {  92, 539 }, {  93, 539 }, {  94, 539 },
 {  95, 539 }, {  96, 539 }, {  97, 539 }, {  98, 539 }, {  99, 539 },
 { 100, 539 }, { 101, 539 }, { 102, 539 }, { 103, 539 }, { 104, 539 },
 { 105, 539 }, { 106, 539 }, { 107, 539 }, { 108, 539 }, { 109, 539 },
 { 110, 539 }, { 111, 539 }, { 112, 539 }, { 113, 539 }, { 114, 539 },
 { 115, 539 }, { 116, 539 }, { 117, 539 }, { 118, 539 }, { 119, 539 },

 { 120, 539 }, { 121, 539 }, { 122, 539 }, { 123, 539 }, { 124, 539 },
 { 125, 539 }, { 126, 539 }, { 127, 539 }, { 128, 539 }, { 129, 539 },
 { 130, 539 }, { 131, 539 }, { 132, 539 }, { 133, 539 }, { 134, 539 },
 { 135, 539 }, { 136, 539 }, { 137, 539 }, { 138, 539 }, { 139, 539 },
 { 140, 539 }, { 141, 539 }, { 142, 539 }, { 143, 539 }, { 144, 539 },
 { 145, 539 }, { 146, 539 }, { 147, 539 }, { 148, 539 }, { 149, 539 },
 { 150, 539 }, { 151, 539 }, { 152, 539 }, { 153, 539 }, { 154, 539 },
 { 155, 539 }, { 156, 539 }, { 157, 539 }, { 158, 539 }, { 159, 539 },
 { 160, 539 }, { 161, 539 }, { 162, 539 }, { 163, 539 }, { 164, 539 },
 { 165, 539 }, { 166, 539 }, { 167, 539 }, { 168, 539 }, { 169, 539 },

 { 170, 539 }, { 171, 539 }, { 172, 539 }, { 173, 539 }, { 174, 539 },
 { 175, 539 }, { 176, 539 }, { 177, 539 }, { 178, 539 }, { 179, 539 },
 { 180, 539 }, { 181, 539 }, { 182, 539 }, { 183, 539 }, { 184, 539 },
 { 185, 539 }, { 186, 539 }, { 187, 539 }, { 188, 539 }, { 189, 539 },
 { 190, 539 }, { 191, 539 }, { 192, 539 }, { 193, 539 }, { 194, 539 },
 { 195, 539 }, { 196, 539 }, { 197, 539 }, { 198, 539 }, { 199, 539 },
 { 200, 539 }, { 201, 539 }, { 202, 539 }, { 203, 539 }, { 204, 539 },
 { 205, 539 }, { 206, 539 }, { 207, 539 }, { 208, 539 }, { 209, 539 },
 { 210, 539 }, { 211, 539 }, { 212, 539 }, { 213, 539 }, { 214, 539 },
 { 215, 539 }, { 216, 539 }, { 217, 539 }, { 218, 539 }, { 219, 539 },

 { 220, 539 }, { 221, 539 }, { 222, 539 }, { 223, 539 }, { 224, 539 },
 { 225, 539 }, { 226, 539 }, { 227, 539 }, { 228, 539 }, { 229, 539 },
 { 230, 539 }, { 231, 539 }, { 232, 539 }, { 233, 539 }, { 234, 539 },
 { 235, 539 }, { 236, 539 }, { 237, 539 }, { 238, 539 }, { 239, 539 },
 { 240, 539 }, { 241, 539 }, { 242, 539 }, { 243, 539 }, { 244, 539 },
 { 245, 539 }, { 246, 539 }, { 247, 539 }, { 248, 539 }, { 249, 539 },
 { 250, 539 }, { 251, 539 }, { 252, 539 }, { 253, 539 }, { 254, 539 },
 { 255, 539 }, { 256, 539 }, {   0,   1 }, {   0, 539 }, {   0,   7 },
 {   0, 537 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   9,   0 }, {  10,   0 }, {  11,   0 },

 {  12,   0 }, {  13,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   6 }, {   0, 515 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  32,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,   0 }, {  49,   0 },
 {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 }, {  54,   0 },
 {  55,   0 }, {  56,   0 }, {  57,   0 }, {  36,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  48,   0 }, {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 },
 {  53,   0 }, {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  65,   0 }, {  66,   0 }, {  67,   0 },
 {  68,   0 }, {  69,   0 }, {  70,   0 }, {  71,   0 }, {  72,   0 },
 {  73,   0 }, {  74,   0 }, {  75,   0 }, {  76,   0 }, {  77,   0 },
 {  78,   0 }, {  79,   0 }, {  80,   0 }, {  81,   0 }, {  82,   0 },
 {  83,   0 }, {  84,   0 }, {  85,   0 }, {  86,   0 }, {  87,   0 },

 {  88,   0 }, {  89,   0 }, {  90,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  95,   0 }, {   0,   0 }, {  97,   0 },
 {  98,   0 }, {  99,   0 }, { 100,   0 }, { 101,   0 }, { 102,   0 },
 { 103,   0 }, { 104,   0 }, { 105,   0 }, { 106,   0 }, { 107,   0 },
 { 108,   0 }, { 109,   0 }, { 110,   0 }, { 111,   0 }, { 112,   0 },
 { 113,   0 }, { 114,   0 }, { 115,   0 }, { 116,   0 }, { 117,   0 },
 { 118,   0 }, { 119,   0 }, { 120,   0 }, { 121,   0 }, { 122,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 { 128,   0 }, { 129,   0 }, { 130,   0 }, { 131,   0 }, { 132,   0 },
 { 133,   0 }, { 134,   0 }, { 135,   0 }, { 136,   0 }, { 137,   0 },

 { 138,   0 }, { 139,   0 }, { 140,   0 }, { 141,   0 }, { 142,   0 },
 { 143,   0 }, { 144,   0 }, { 145,   0 }, { 146,   0 }, { 147,   0 },
 { 148,   0 }, { 149,   0 }, { 150,   0 }, { 151,   0 }, { 152,   0 },
 { 153,   0 }, { 154,   0 }, { 155,   0 }, { 156,   0 }, { 157,   0 },
 { 158,   0 }, { 159,   0 }, { 160,   0 }, { 161,   0 }, { 162,   0 },
 { 163,   0 }, { 164,   0 }, { 165,   0 }, { 166,   0 }, { 167,   0 },
 { 168,   0 }, { 169,   0 }, { 170,   0 }, { 171,   0 }, { 172,   0 },
 { 173,   0 }, { 174,   0 }, { 175,   0 }, { 176,   0 }, { 177,   0 },
 { 178,   0 }, { 179,   0 }, { 180,   0 }, { 181,   0 }, { 182,   0 },
 { 183,   0 }, { 184,   0 }, { 185,   0 }, { 186,   0 }, { 187,   0 },

 { 188,   0 }, { 189,   0 }, { 190,   0 }, { 191,   0 }, { 192,   0 },
 { 193,   0 }, { 194,   0 }, { 195,   0 }, { 196,   0 }, { 197,   0 },
 { 198,   0 }, { 199,   0 }, { 200,   0 }, { 201,   0 }, { 202,   0 },
 { 203,   0 }, { 204,   0 }, { 205,   0 }, { 206,   0 }, { 207,   0 },
 { 208,   0 }, { 209,   0 }, { 210,   0 }, { 211,   0 }, { 212,   0 },
 { 213,   0 }, { 214,   0 }, { 215,   0 }, { 216,   0 }, { 217,   0 },
 { 218,   0 }, { 219,   0 }, { 220,   0 }, { 221,   0 }, { 222,   0 },
 { 223,   0 }, { 224,   0 }, { 225,   0 }, { 226,   0 }, { 227,   0 },
 { 228,   0 }, { 229,   0 }, { 230,   0 }, { 231,   0 }, { 232,   0 },
 { 233,   0 }, { 234,   0 }, { 235,   0 }, { 236,   0 }, { 237,   0 },

 { 238,   0 }, { 239,   0 }, { 240,   0 }, { 241,   0 }, { 242,   0 },
 { 243,   0 }, { 244,   0 }, { 245,   0 }, { 246,   0 }, { 247,   0 },
 { 248,   0 }, { 249,   0 }, { 250,   0 }, { 251,   0 }, { 252,   0 },
 { 253,   0 }, { 254,   0 }, { 255,   0 }, {   0,   4 }, {   0, 258 },
 {   1,   0 }, {   2,   0 }, {   3,   0 }, {   4,   0 }, {   5,   0 },
 {   6,   0 }, {   7,   0 }, {   8,   0 }, {   9,   0 }, {  10,   0 },
 {  11,   0 }, {  12,   0 }, {  13,   0 }, {  14,   0 }, {  15,   0 },
 {  16,   0 }, {  17,   0 }, {  18,   0 }, {  19,   0 }, {  20,   0 },
 {  21,   0 }, {  22,   0 }, {  23,   0 }, {  24,   0 }, {  25,   0 },
 {  26,   0 }, {  27,   0 }, {  28,   0 }, {  29,   0 }, {  30,   0 },

 {  31,   0 }, {  32,   0 }, {  33,   0 }, {   0,   0 }, {  35,   0 },
 {  36,   0 }, {  37,   0 }, {  38,   0 }, {  39,   0 }, {  40,   0 },
 {  41,   0 }, {  42,   0 }, {  43,   0 }, {  44,   0 }, {  45,   0 },
 {  46,   0 }, {  47,   0 }, {  48,   0 }, {  49,   0 }, {  50,   0 },
 {  51,   0 }, {  52,   0 }, {  53,   0 }, {  54,   0 }, {  55,   0 },
 {  56,   0 }, {  57,   0 }, {  58,   0 }, {  59,   0 }, {  60,   0 },
 {  61,   0 }, {  62,   0 }, {  63,   0 }, {  64,   0 }, {  65,   0 },
 {  66,   0 }, {  67,   0 }, {  68,   0 }, {  69,   0 }, {  70,   0 },
 {  71,   0 }, {  72,   0 }, {  73,   0 }, {  74,   0 }, {  75,   0 },
 {  76,   0 }, {  77,   0 }, {  78,   0 }, {  79,   0 }, {  80,   0 },

 {  81,   0 }, {  82,   0 }, {  83,   0 }, {  84,   0 }, {  85,   0 },
 {  86,   0 }, {  87,   0 }, {  88,   0 }, {  89,   0 }, {  90,   0 },
 {  91,   0 }, {  92,   0 }, {  93,   0 }, {  94,   0 }, {  95,   0 },
 {  96,   0 }, {  97,   0 }, {  98,   0 }, {  99,   0 }, { 100,   0 },
 { 101,   0 }, { 102,   0 }, { 103,   0 }, { 104,   0 }, { 105,   0 },
 { 106,   0 }, { 107,   0 }, { 108,   0 }, { 109,   0 }, { 110,   0 },
 { 111,   0 }, { 112,   0 }, { 113,   0 }, { 114,   0 }, { 115,   0 },
 { 116,   0 }, { 117,   0 }, { 118,   0 }, { 119,   0 }, { 120,   0 },
 { 121,   0 }, { 122,   0 }, { 123,   0 }, { 124,   0 }, { 125,   0 },
 { 126,   0 }, { 127,   0 }, { 128,   0 }, { 129,   0 }, { 130,   0 },

 { 131,   0 }, { 132,   0 }, { 133,   0 }, { 134,   0 }, { 135,   0 },
 { 136,   0 }, { 137,   0 }, { 138,   0 }, { 139,   0 }, { 140,   0 },
 { 141,   0 }, { 142,   0 }, { 143,   0 }, { 144,   0 }, { 145,   0 },
 { 146,   0 }, { 147,   0 }, { 148,   0 }, { 149,   0 }, { 150,   0 },
 { 151,   0 }, { 152,   0 }, { 153,   0 }, { 154,   0 }, { 155,   0 },
 { 156,   0 }, { 157,   0 }, { 158,   0 }, { 159,   0 }, { 160,   0 },
 { 161,   0 }, { 162,   0 }, { 163,   0 }, { 164,   0 }, { 165,   0 },
 { 166,   0 }, { 167,   0 }, { 168,   0 }, { 169,   0 }, { 170,   0 },
 { 171,   0 }, { 172,   0 }, { 173,   0 }, { 174,   0 }, { 175,   0 },
 { 176,   0 }, { 177,   0 }, { 178,   0 }, { 179,   0 }, { 180,   0 },

 { 181,   0 }, { 182,   0 }, { 183,   0 }, { 184,   0 }, { 185,   0 },
 { 186,   0 }, { 187,   0 }, { 188,   0 }, { 189,   0 }, { 190,   0 },
 { 191,   0 }, { 192,   0 }, { 193,   0 }, { 194,   0 }, { 195,   0 },
 { 196,   0 }, { 197,   0 }, { 198,   0 }, { 199,   0 }, { 200,   0 },
 { 201,   0 }, { 202,   0 }, { 203,   0 }, { 204,   0 }, { 205,   0 },
 { 206,   0 }, { 207,   0 }, { 208,   0 }, { 209,   0 }, { 210,   0 },
 { 211,   0 }, { 212,   0 }, { 213,   0 }, { 214,   0 }, { 215,   0 },
 { 216,   0 }, { 217,   0 }, { 218,   0 }, { 219,   0 }, { 220,   0 },
 { 221,   0 }, { 222,   0 }, { 223,   0 }, { 224,   0 }, { 225,   0 },
 { 226,   0 }, { 227,   0 }, { 228,   0 }, { 229,   0 }, { 230,   0 },

 { 231,   0 }, { 232,   0 }, { 233,   0 }, { 234,   0 }, { 235,   0 },
 { 236,   0 }, { 237,   0 }, { 238,   0 }, { 239,   0 }, { 240,   0 },
 { 241,   0 }, { 242,   0 }, { 243,   0 }, { 244,   0 }, { 245,   0 },
 { 246,   0 }, { 247,   0 }, { 248,   0 }, { 249,   0 }, { 250,   0 },
 { 251,   0 }, { 252,   0 }, { 253,   0 }, { 254,   0 }, { 255,   0 },
 { 256,   0 }, { 257,  14 }, {   1,   0 },    };

static const struct yy_trans_info *yy_start_state_list[5] =
    {
    &yy_transition[1],
    &yy_transition[3],
    &yy_transition[261],
    &yy_transition[519],
    &yy_transition[777],

    } ;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "syncrep_scanner.l"
#line 2 "syncrep_scanner.l"
/*-------------------------------------------------------------------------
 *
 * syncrep_scanner.l
 *	  a lexical scanner for synchronous_standby_names
 *
 * Portions Copyright (c) 1996-2016, PostgreSQL Global Development Group
 * Portions Copyright (c) 1994, Regents of the University of California
 *
 *
 * IDENTIFICATION
 *	  src/backend/replication/syncrep_scanner.l
 *
 *-------------------------------------------------------------------------
 */
#include "postgres.h"

#include "lib/stringinfo.h"

/* Avoid exit() on fatal scanner errors (a bit ugly -- see yy_fatal_error) */
#undef fprintf
#define fprintf(file, fmt, msg)  fprintf_to_ereport(fmt, msg)

static void
fprintf_to_ereport(const char *fmt, const char *msg)
{
	ereport(ERROR, (errmsg_internal("%s", msg)));
}

/* Handles to the buffer that the lexer uses internally */
static YY_BUFFER_STATE scanbufhandle;

static StringInfoData xdbuf;

#line 1152 "syncrep_scanner.c"
#define YY_NO_INPUT 1
/*
 * <xd> delimited identifiers (double-quoted identifiers)
 */

#line 1158 "syncrep_scanner.c"

#define INITIAL 0
#define xd 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 64 "syncrep_scanner.l"

#line 1376 "syncrep_scanner.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yy_start_state_list[(yy_start)];
yy_match:
		{
		const struct yy_trans_info *yy_trans_info;

		YY_CHAR yy_c;

		for ( yy_c = YY_SC_TO_UI(*yy_cp);
		      (yy_trans_info = &yy_current_state[yy_c])->
		yy_verify == yy_c;
		      yy_c = YY_SC_TO_UI(*++yy_cp) )
			yy_current_state += yy_trans_info->yy_nxt;
		}

yy_find_action:
		yy_act = yy_current_state[-1].yy_nxt;

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 65 "syncrep_scanner.l"
{ /* ignore */ }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 67 "syncrep_scanner.l"
{
				initStringInfo(&xdbuf);
				BEGIN(xd);
		}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 71 "syncrep_scanner.l"
{
				appendStringInfoChar(&xdbuf, '"');
		}
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 74 "syncrep_scanner.l"
{
				appendStringInfoString(&xdbuf, yytext);
		}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 77 "syncrep_scanner.l"
{
				yylval.str = xdbuf.data;
				xdbuf.data = NULL;
				BEGIN(INITIAL);
				return NAME;
		}
	YY_BREAK
case YY_STATE_EOF(xd):
#line 83 "syncrep_scanner.l"
{
				yyerror("unterminated quoted identifier");
				return JUNK;
		}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 88 "syncrep_scanner.l"
{
				yylval.str = pstrdup(yytext);
				return NAME;
		}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 93 "syncrep_scanner.l"
{
				yylval.str = pstrdup(yytext);
				return NUM;
		}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 98 "syncrep_scanner.l"
{
				yylval.str = "*";
				return NAME;
		}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 103 "syncrep_scanner.l"
{ return ','; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 104 "syncrep_scanner.l"
{ return '('; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 105 "syncrep_scanner.l"
{ return ')'; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 107 "syncrep_scanner.l"
{ return JUNK; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 108 "syncrep_scanner.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1508 "syncrep_scanner.c"
			case YY_STATE_EOF(INITIAL):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = yy_start_state_list[(yy_start)];

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		yy_current_state += yy_current_state[(*yy_cp ? YY_SC_TO_UI(*yy_cp) : 256)].yy_nxt;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    
	int yy_c = 256;
	const struct yy_trans_info *yy_trans_info;

	yy_trans_info = &yy_current_state[(unsigned int) yy_c];
	yy_current_state += yy_trans_info->yy_nxt;
	yy_is_jam = (yy_trans_info->yy_verify != yy_c);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 108 "syncrep_scanner.l"



/* Needs to be here for access to yytext */
void
syncrep_yyerror(const char *message)
{
	/* report only the first error in a parse operation */
	if (syncrep_parse_error_msg)
		return;
	if (yytext[0])
		syncrep_parse_error_msg = psprintf("%s at or near \"%s\"",
										   message, yytext);
	else
		syncrep_parse_error_msg = psprintf("%s at end of input",
										   message);
}

void
syncrep_scanner_init(const char *str)
{
	Size		slen = strlen(str);
	char	   *scanbuf;

	/*
	 * Might be left over after ereport()
	 */
	if (YY_CURRENT_BUFFER)
		yy_delete_buffer(YY_CURRENT_BUFFER);

	/*
	 * Make a scan buffer with special termination needed by flex.
	 */
	scanbuf = (char *) palloc(slen + 2);
	memcpy(scanbuf, str, slen);
	scanbuf[slen] = scanbuf[slen + 1] = YY_END_OF_BUFFER_CHAR;
	scanbufhandle = yy_scan_buffer(scanbuf, slen + 2);

	/* Make sure we start in proper state */
	BEGIN(INITIAL);
}

void
syncrep_scanner_finish(void)
{
	yy_delete_buffer(scanbufhandle);
	scanbufhandle = NULL;
}

